pub enum DeviceIdError {
BackendSpecific {
err: BackendSpecificError,
},
UnsupportedPlatform,
}Expand description
An error that may occur while attempting to retrieve a device ID.
Variants
BackendSpecific
See the BackendSpecificError docs for more information about this error variant.
Fields
UnsupportedPlatform