assert_stream_send

Macro assert_stream_send 

macro_rules! assert_stream_send {
    ($t:ty) => { ... };
}
Compile-time assertion that a stream type implements Send.

Custom host implementations should use this macro to verify their Stream type can be safely transferred between threads, as required by CPAL’s API.

Example

use cpal::assert_stream_send;
struct MyStream { /* ... */ }
assert_stream_send!(MyStream);