assert_stream_sync

Macro assert_stream_sync 

macro_rules! assert_stream_sync {
    ($t:ty) => { ... };
}
Compile-time assertion that a stream type implements Sync.

Custom host implementations should use this macro to verify their Stream type can be safely shared between threads, as required by CPAL’s API.

Example

use cpal::assert_stream_sync;
struct MyStream { /* ... */ }
assert_stream_sync!(MyStream);