pub struct U24(/* private fields */);Expand description
24-bit unsigned integer sample type.
Represents 24-bit audio with range 0..=((1 << 24) - 1), with origin at 1 << 23 == 8388608.
Note: While representing 24-bit audio, this format uses 4 bytes (u32) of storage
with the most significant byte unused. Use SampleFormat::bits_per_sample to get
the actual bit depth (24) vs SampleFormat::sample_size for storage size (4 bytes).
Implementations
Sourceimpl U24
impl U24
Sourcepub fn new(val: i32) -> Option<U24>
pub fn new(val: i32) -> Option<U24>
Construct a new sample if the given value is within range.
Returns None if val is out of range.
Sourcepub fn new_unchecked(s: i32) -> U24
pub fn new_unchecked(s: i32) -> U24
Constructs a new sample without checking for overflowing.
This should only be used if the user can guarantee the sample will be within range and they require the extra performance.
If this function is used, the sample crate can’t guarantee that the returned sample or any interacting samples will remain within their MIN and MAX bounds.